import gi

gi.require_version("Gtk", "3.0")
from gi.repository import Gtk
from gi.repository import Gdk

import os

def onDestroy(self, *args):
	Gtk.main_quit()

def on_cancelBtn(button):
	Gtk.main_quit()

def on_okBtn(button):
	global selectedItem
	global itemSelection
	global itemResults
	model, pathList = itemSelection.get_selected_rows()
	for onePath in pathList:
		mulInxList = onePath.get_indices()
		if len(mulInxList) > 0:
			if len(selectedItem) > 0:
				selectedItem += "|" + itemResults[mulInxList[0]]
			else:
				selectedItem = itemResults[mulInxList[0]]
	Gtk.main_quit()

def doSelItem(winSets, labData, itemsFN):
	global selectedItem
	global itemResults
	global itemSelection

	selectedItem = ""
	itemResults = []

	binDir, exe = __file__.rsplit('/', 1)
	binDir = binDir + '/'

	homeDir = os.path.expanduser('~')

	mainWin = Gtk.Window()
	mainWin.connect("destroy", onDestroy)
	mainWin.set_border_width(10)
	mainWin.set_position(Gtk.WindowPosition.CENTER)

	useMono = False
	useMulti = False
	vSpacing = 10
	lSpacing = 1
	defWd = -1
	defHt = -1
	for oneSet in winSets:
		if oneSet:
			if '=' in oneSet:
				key, val = oneSet.split("=", 1)
				if key == "t":
					mainWin.set_title(val)
				elif key == "i":
					mainWin.set_icon_from_file(val)
				elif key == "w":
					defWd = int(val)
				elif key == "h":
					defHt = int(val)
				elif key == "v":
					vSpacing = int(val)
				elif key == "l":
					lSpacing = int(val)
				elif key == "u":
					useMulti = val.startswith("y") or val.startswith("Y")
				elif key == "m":
					useMono = val.startswith("y") or val.startswith("Y")
	if defWd > 0 or defHt > 0:
		mainWin.set_default_size(defWd, defHt)

	vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=vSpacing)
	mainWin.add(vbox)

	lbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=lSpacing)
	for oneLab in labData:
		label = Gtk.Label()
		if oneLab.startswith("["):
			label.set_xalign(0.0)
			oneLab = oneLab[1:]
		if oneLab.startswith("^"):
			label.set_name("ghilab")
			oneLab = oneLab[1:]
		if '<' in oneLab:
			label.set_markup(oneLab)
		else:
			label.set_text(oneLab)
		lbox.pack_start(label, True, True, 0)
	vbox.pack_start(lbox, False, True, 0)

	itemStore = Gtk.ListStore(str)
	itemStore.clear()
	defInx = -1
	indx = 0
	with open(itemsFN,'r') as itemData:
		for oneItem in itemData:
			if oneItem:
				if '=' in oneItem:
					key, val = oneItem.rstrip('\n').split("=", 1)
					if key and val:
						if key.startswith("^"):
							defInx = indx
							key = key[1:]
						itemResults.append(key)
						treeiter = itemStore.append([val])
						indx += 1

	itemView = Gtk.TreeView(model=itemStore)
	itemView.set_headers_visible(False)
	itemView.set_hexpand(True)
	itemView.set_vexpand(True)
	renderer = Gtk.CellRendererText()
	if useMono:
		renderer.set_property("family", "Monospace")
	column = Gtk.TreeViewColumn(cell_renderer=renderer, text=0)
	itemView.append_column(column)

	itemSelection = itemView.get_selection()
	if useMulti:
		itemSelection.set_mode(Gtk.SelectionMode.MULTIPLE)
	else:
		itemSelection.set_mode(Gtk.SelectionMode.BROWSE)

	itemScrollWin = Gtk.ScrolledWindow()
	itemScrollWin.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.ALWAYS)
	itemScrollWin.set_hexpand(True)
	itemScrollWin.set_vexpand(True)
	itemScrollWin.set_overlay_scrolling(False)
	itemScrollWin.set_kinetic_scrolling(False)
	itemScrollWin.add(itemView)

	vbox.pack_start(itemScrollWin, True, True, 0)

	hbox = Gtk.ButtonBox()
	hbox.set_homogeneous(True)
	hbox.set_layout(Gtk.ButtonBoxStyle.SPREAD)

	button = Gtk.Button.new_with_label("Cancel")
	button.set_image(Gtk.Image.new_from_file(binDir + "icons/cancel.svg"))
	button.connect("clicked", on_cancelBtn)
	hbox.pack_start(button, True, True, 0)

	button = Gtk.Button.new_with_label("Ok")
	button.set_image(Gtk.Image.new_from_file(binDir + "icons/ok.svg"))
	button.connect("clicked", on_okBtn)
	hbox.pack_start(button, True, True, 0)

	vbox.pack_start(hbox, False, True, 0)

	cssPath = os.path.join(homeDir, '.config', 'ggwins.css')
	if not os.path.exists(cssPath):
		cssPath = os.path.join(binDir,  'ggwins.css')
		if not os.path.exists(cssPath):
			cssPath = ''
	if cssPath:
		provider = Gtk.CssProvider()
		provider.load_from_path(cssPath)
		Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(), provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)

	mainWin.show_all()

	if defInx == -1:
		itemSelection.unselect_all()
	else:
		itemSelection.select_path(Gtk.TreePath(defInx))
		itemView.scroll_to_cell(Gtk.TreePath(defInx), None, True, 0.5, 0.0)

	Gtk.main()
	return selectedItem
